{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "F94-RfDfD3GF",
   "metadata": {
    "id": "F94-RfDfD3GF"
   },
   "source": [
    "# Mining ERT database\n",
    "\n",
    "This webpage presents the database of studies applying **Electrical Resistivity Tomography** (ERT) in the context of **mining wastes**. **Over 100 studies** using ERT, published from 1990 to 2020, have been identified for the review. Each study has been classified according to the type of application. \n",
    "\n",
    "This database may be of help to describe the **developments of ERT** for mining waste **valorization**, mining waste **characterization** and mining waste **stability monitoring**. You may also use it to **find relevant references** for your field of expertise !\n",
    "\n",
    "Moreover, this review helps identifying **future promising applications of TL-ERT for long-term mining waste monitoring**."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e9124658",
   "metadata": {},
   "source": [
    "```{admonition} Download\n",
    "Feel free to **explore** and **download** the database .csv file [in the github project](https://github.com/AdriDim/review2022) after citing us! \n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "1e004001",
   "metadata": {},
   "source": [
    "## Quick look at the database\n",
    "\n",
    "The **mining waste ERT database** references published studies from 1990 to 2020 using ERT for mining waste imaging and monitoring. Each study is identified by an unique **ID** (the name of the main author and the year of publication). Other characteristics have also been recorded in the database such as the **title** of the study, the **journal** where it has been published, the **type of application**, the **country** where the study has been carried out and others.\n",
    "\n",
    "As described in the review, the types of applications have been classified into three broader categories : \n",
    "- **Mining waste valorization** _(Tool for heap leaching, revalorization of mineralized wastes)_\n",
    "- **Mining waste characterization** _(Waste characterization, acid mine drainage detection)_\n",
    "- **Mining waste monitoring** _(Geochemical and geotechnical mining waste stability monitoring)_\n",
    "\n",
    "### Example of ERT for acid mine drainage (AMD) detection\n",
    "\n",
    "```{admonition} Example !\n",
    "Here is an example for studies using ERT to detect and map AMD. \n",
    "```"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "RpCZarTqIPl-",
   "metadata": {
    "cellView": "form",
    "id": "RpCZarTqIPl-",
    "tags": [
     "remove-input",
     "remove-output"
    ]
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/home/adimech/.local/lib/python3.6/site-packages/pandas/compat/__init__.py:120: UserWarning: Could not import the lzma module. Your installed Python is incomplete. Attempting to use lzma compression will result in a RuntimeError.\n",
      "  warnings.warn(msg)\n"
     ]
    }
   ],
   "source": [
    "import pandas as pd\n",
    "url='https://raw.githubusercontent.com/AdriDim/review2022/main/data/database_ert_mining_studies.csv'\n",
    "df = pd.read_csv(url, skiprows=0, sep=';')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "2e047e50",
   "metadata": {
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "    <div class=\"bk-root\">\n",
       "        <a href=\"https://bokeh.org\" target=\"_blank\" class=\"bk-logo bk-logo-small bk-logo-notebook\"></a>\n",
       "        <span id=\"1002\">Loading BokehJS ...</span>\n",
       "    </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "\n",
       "(function(root) {\n",
       "  function now() {\n",
       "    return new Date();\n",
       "  }\n",
       "\n",
       "  var force = true;\n",
       "\n",
       "  if (typeof root._bokeh_onload_callbacks === \"undefined\" || force === true) {\n",
       "    root._bokeh_onload_callbacks = [];\n",
       "    root._bokeh_is_loading = undefined;\n",
       "  }\n",
       "\n",
       "  var JS_MIME_TYPE = 'application/javascript';\n",
       "  var HTML_MIME_TYPE = 'text/html';\n",
       "  var EXEC_MIME_TYPE = 'application/vnd.bokehjs_exec.v0+json';\n",
       "  var CLASS_NAME = 'output_bokeh rendered_html';\n",
       "\n",
       "  /**\n",
       "   * Render data to the DOM node\n",
       "   */\n",
       "  function render(props, node) {\n",
       "    var script = document.createElement(\"script\");\n",
       "    node.appendChild(script);\n",
       "  }\n",
       "\n",
       "  /**\n",
       "   * Handle when an output is cleared or removed\n",
       "   */\n",
       "  function handleClearOutput(event, handle) {\n",
       "    var cell = handle.cell;\n",
       "\n",
       "    var id = cell.output_area._bokeh_element_id;\n",
       "    var server_id = cell.output_area._bokeh_server_id;\n",
       "    // Clean up Bokeh references\n",
       "    if (id != null && id in Bokeh.index) {\n",
       "      Bokeh.index[id].model.document.clear();\n",
       "      delete Bokeh.index[id];\n",
       "    }\n",
       "\n",
       "    if (server_id !== undefined) {\n",
       "      // Clean up Bokeh references\n",
       "      var cmd = \"from bokeh.io.state import curstate; print(curstate().uuid_to_server['\" + server_id + \"'].get_sessions()[0].document.roots[0]._id)\";\n",
       "      cell.notebook.kernel.execute(cmd, {\n",
       "        iopub: {\n",
       "          output: function(msg) {\n",
       "            var id = msg.content.text.trim();\n",
       "            if (id in Bokeh.index) {\n",
       "              Bokeh.index[id].model.document.clear();\n",
       "              delete Bokeh.index[id];\n",
       "            }\n",
       "          }\n",
       "        }\n",
       "      });\n",
       "      // Destroy server and session\n",
       "      var cmd = \"import bokeh.io.notebook as ion; ion.destroy_server('\" + server_id + \"')\";\n",
       "      cell.notebook.kernel.execute(cmd);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  /**\n",
       "   * Handle when a new output is added\n",
       "   */\n",
       "  function handleAddOutput(event, handle) {\n",
       "    var output_area = handle.output_area;\n",
       "    var output = handle.output;\n",
       "\n",
       "    // limit handleAddOutput to display_data with EXEC_MIME_TYPE content only\n",
       "    if ((output.output_type != \"display_data\") || (!Object.prototype.hasOwnProperty.call(output.data, EXEC_MIME_TYPE))) {\n",
       "      return\n",
       "    }\n",
       "\n",
       "    var toinsert = output_area.element.find(\".\" + CLASS_NAME.split(' ')[0]);\n",
       "\n",
       "    if (output.metadata[EXEC_MIME_TYPE][\"id\"] !== undefined) {\n",
       "      toinsert[toinsert.length - 1].firstChild.textContent = output.data[JS_MIME_TYPE];\n",
       "      // store reference to embed id on output_area\n",
       "      output_area._bokeh_element_id = output.metadata[EXEC_MIME_TYPE][\"id\"];\n",
       "    }\n",
       "    if (output.metadata[EXEC_MIME_TYPE][\"server_id\"] !== undefined) {\n",
       "      var bk_div = document.createElement(\"div\");\n",
       "      bk_div.innerHTML = output.data[HTML_MIME_TYPE];\n",
       "      var script_attrs = bk_div.children[0].attributes;\n",
       "      for (var i = 0; i < script_attrs.length; i++) {\n",
       "        toinsert[toinsert.length - 1].firstChild.setAttribute(script_attrs[i].name, script_attrs[i].value);\n",
       "        toinsert[toinsert.length - 1].firstChild.textContent = bk_div.children[0].textContent\n",
       "      }\n",
       "      // store reference to server id on output_area\n",
       "      output_area._bokeh_server_id = output.metadata[EXEC_MIME_TYPE][\"server_id\"];\n",
       "    }\n",
       "  }\n",
       "\n",
       "  function register_renderer(events, OutputArea) {\n",
       "\n",
       "    function append_mime(data, metadata, element) {\n",
       "      // create a DOM node to render to\n",
       "      var toinsert = this.create_output_subarea(\n",
       "        metadata,\n",
       "        CLASS_NAME,\n",
       "        EXEC_MIME_TYPE\n",
       "      );\n",
       "      this.keyboard_manager.register_events(toinsert);\n",
       "      // Render to node\n",
       "      var props = {data: data, metadata: metadata[EXEC_MIME_TYPE]};\n",
       "      render(props, toinsert[toinsert.length - 1]);\n",
       "      element.append(toinsert);\n",
       "      return toinsert\n",
       "    }\n",
       "\n",
       "    /* Handle when an output is cleared or removed */\n",
       "    events.on('clear_output.CodeCell', handleClearOutput);\n",
       "    events.on('delete.Cell', handleClearOutput);\n",
       "\n",
       "    /* Handle when a new output is added */\n",
       "    events.on('output_added.OutputArea', handleAddOutput);\n",
       "\n",
       "    /**\n",
       "     * Register the mime type and append_mime function with output_area\n",
       "     */\n",
       "    OutputArea.prototype.register_mime_type(EXEC_MIME_TYPE, append_mime, {\n",
       "      /* Is output safe? */\n",
       "      safe: true,\n",
       "      /* Index of renderer in `output_area.display_order` */\n",
       "      index: 0\n",
       "    });\n",
       "  }\n",
       "\n",
       "  // register the mime type if in Jupyter Notebook environment and previously unregistered\n",
       "  if (root.Jupyter !== undefined) {\n",
       "    var events = require('base/js/events');\n",
       "    var OutputArea = require('notebook/js/outputarea').OutputArea;\n",
       "\n",
       "    if (OutputArea.prototype.mime_types().indexOf(EXEC_MIME_TYPE) == -1) {\n",
       "      register_renderer(events, OutputArea);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  \n",
       "  if (typeof (root._bokeh_timeout) === \"undefined\" || force === true) {\n",
       "    root._bokeh_timeout = Date.now() + 5000;\n",
       "    root._bokeh_failed_load = false;\n",
       "  }\n",
       "\n",
       "  var NB_LOAD_WARNING = {'data': {'text/html':\n",
       "     \"<div style='background-color: #fdd'>\\n\"+\n",
       "     \"<p>\\n\"+\n",
       "     \"BokehJS does not appear to have successfully loaded. If loading BokehJS from CDN, this \\n\"+\n",
       "     \"may be due to a slow or bad network connection. Possible fixes:\\n\"+\n",
       "     \"</p>\\n\"+\n",
       "     \"<ul>\\n\"+\n",
       "     \"<li>re-rerun `output_notebook()` to attempt to load from CDN again, or</li>\\n\"+\n",
       "     \"<li>use INLINE resources instead, as so:</li>\\n\"+\n",
       "     \"</ul>\\n\"+\n",
       "     \"<code>\\n\"+\n",
       "     \"from bokeh.resources import INLINE\\n\"+\n",
       "     \"output_notebook(resources=INLINE)\\n\"+\n",
       "     \"</code>\\n\"+\n",
       "     \"</div>\"}};\n",
       "\n",
       "  function display_loaded() {\n",
       "    var el = document.getElementById(\"1002\");\n",
       "    if (el != null) {\n",
       "      el.textContent = \"BokehJS is loading...\";\n",
       "    }\n",
       "    if (root.Bokeh !== undefined) {\n",
       "      if (el != null) {\n",
       "        el.textContent = \"BokehJS \" + root.Bokeh.version + \" successfully loaded.\";\n",
       "      }\n",
       "    } else if (Date.now() < root._bokeh_timeout) {\n",
       "      setTimeout(display_loaded, 100)\n",
       "    }\n",
       "  }\n",
       "\n",
       "\n",
       "  function run_callbacks() {\n",
       "    try {\n",
       "      root._bokeh_onload_callbacks.forEach(function(callback) {\n",
       "        if (callback != null)\n",
       "          callback();\n",
       "      });\n",
       "    } finally {\n",
       "      delete root._bokeh_onload_callbacks\n",
       "    }\n",
       "    console.debug(\"Bokeh: all callbacks have finished\");\n",
       "  }\n",
       "\n",
       "  function load_libs(css_urls, js_urls, callback) {\n",
       "    if (css_urls == null) css_urls = [];\n",
       "    if (js_urls == null) js_urls = [];\n",
       "\n",
       "    root._bokeh_onload_callbacks.push(callback);\n",
       "    if (root._bokeh_is_loading > 0) {\n",
       "      console.debug(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n",
       "      return null;\n",
       "    }\n",
       "    if (js_urls == null || js_urls.length === 0) {\n",
       "      run_callbacks();\n",
       "      return null;\n",
       "    }\n",
       "    console.debug(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n",
       "    root._bokeh_is_loading = css_urls.length + js_urls.length;\n",
       "\n",
       "    function on_load() {\n",
       "      root._bokeh_is_loading--;\n",
       "      if (root._bokeh_is_loading === 0) {\n",
       "        console.debug(\"Bokeh: all BokehJS libraries/stylesheets loaded\");\n",
       "        run_callbacks()\n",
       "      }\n",
       "    }\n",
       "\n",
       "    function on_error(url) {\n",
       "      console.error(\"failed to load \" + url);\n",
       "    }\n",
       "\n",
       "    for (let i = 0; i < css_urls.length; i++) {\n",
       "      const url = css_urls[i];\n",
       "      const element = document.createElement(\"link\");\n",
       "      element.onload = on_load;\n",
       "      element.onerror = on_error.bind(null, url);\n",
       "      element.rel = \"stylesheet\";\n",
       "      element.type = \"text/css\";\n",
       "      element.href = url;\n",
       "      console.debug(\"Bokeh: injecting link tag for BokehJS stylesheet: \", url);\n",
       "      document.body.appendChild(element);\n",
       "    }\n",
       "\n",
       "    const hashes = {\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.3.min.js\": \"dM3QQsP+wXdHg42wTqW85BjZQdLNNIXqlPw/BgKoExPmTG7ZLML4EGqLMfqHT6ON\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.3.min.js\": \"8x57I4YuIfu8XyZfFo0XVr2WAT8EK4rh/uDe3wF7YuW2FNUSNEpJbsPaB1nJ2fz2\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.3.min.js\": \"3QTqdz9LyAm2i0sG5XTePsHec3UHWwVsrOL68SYRoAXsafvfAyqtQ+h440+qIBhS\"};\n",
       "\n",
       "    for (let i = 0; i < js_urls.length; i++) {\n",
       "      const url = js_urls[i];\n",
       "      const element = document.createElement('script');\n",
       "      element.onload = on_load;\n",
       "      element.onerror = on_error.bind(null, url);\n",
       "      element.async = false;\n",
       "      element.src = url;\n",
       "      if (url in hashes) {\n",
       "        element.crossOrigin = \"anonymous\";\n",
       "        element.integrity = \"sha384-\" + hashes[url];\n",
       "      }\n",
       "      console.debug(\"Bokeh: injecting script tag for BokehJS library: \", url);\n",
       "      document.head.appendChild(element);\n",
       "    }\n",
       "  };\n",
       "\n",
       "  function inject_raw_css(css) {\n",
       "    const element = document.createElement(\"style\");\n",
       "    element.appendChild(document.createTextNode(css));\n",
       "    document.body.appendChild(element);\n",
       "  }\n",
       "\n",
       "  \n",
       "  var js_urls = [\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.3.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.3.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.3.min.js\"];\n",
       "  var css_urls = [];\n",
       "  \n",
       "\n",
       "  var inline_js = [\n",
       "    function(Bokeh) {\n",
       "      Bokeh.set_log_level(\"info\");\n",
       "    },\n",
       "    function(Bokeh) {\n",
       "    \n",
       "    \n",
       "    }\n",
       "  ];\n",
       "\n",
       "  function run_inline_js() {\n",
       "    \n",
       "    if (root.Bokeh !== undefined || force === true) {\n",
       "      \n",
       "    for (var i = 0; i < inline_js.length; i++) {\n",
       "      inline_js[i].call(root, root.Bokeh);\n",
       "    }\n",
       "    if (force === true) {\n",
       "        display_loaded();\n",
       "      }} else if (Date.now() < root._bokeh_timeout) {\n",
       "      setTimeout(run_inline_js, 100);\n",
       "    } else if (!root._bokeh_failed_load) {\n",
       "      console.log(\"Bokeh: BokehJS failed to load within specified timeout.\");\n",
       "      root._bokeh_failed_load = true;\n",
       "    } else if (force !== true) {\n",
       "      var cell = $(document.getElementById(\"1002\")).parents('.cell').data().cell;\n",
       "      cell.output_area.append_execute_result(NB_LOAD_WARNING)\n",
       "    }\n",
       "\n",
       "  }\n",
       "\n",
       "  if (root._bokeh_is_loading === 0) {\n",
       "    console.debug(\"Bokeh: BokehJS loaded, going straight to plotting\");\n",
       "    run_inline_js();\n",
       "  } else {\n",
       "    load_libs(css_urls, js_urls, function() {\n",
       "      console.debug(\"Bokeh: BokehJS plotting callback run at\", now());\n",
       "      run_inline_js();\n",
       "    });\n",
       "  }\n",
       "}(window));"
      ],
      "application/vnd.bokehjs_load.v0+json": "\n(function(root) {\n  function now() {\n    return new Date();\n  }\n\n  var force = true;\n\n  if (typeof root._bokeh_onload_callbacks === \"undefined\" || force === true) {\n    root._bokeh_onload_callbacks = [];\n    root._bokeh_is_loading = undefined;\n  }\n\n  \n\n  \n  if (typeof (root._bokeh_timeout) === \"undefined\" || force === true) {\n    root._bokeh_timeout = Date.now() + 5000;\n    root._bokeh_failed_load = false;\n  }\n\n  var NB_LOAD_WARNING = {'data': {'text/html':\n     \"<div style='background-color: #fdd'>\\n\"+\n     \"<p>\\n\"+\n     \"BokehJS does not appear to have successfully loaded. If loading BokehJS from CDN, this \\n\"+\n     \"may be due to a slow or bad network connection. Possible fixes:\\n\"+\n     \"</p>\\n\"+\n     \"<ul>\\n\"+\n     \"<li>re-rerun `output_notebook()` to attempt to load from CDN again, or</li>\\n\"+\n     \"<li>use INLINE resources instead, as so:</li>\\n\"+\n     \"</ul>\\n\"+\n     \"<code>\\n\"+\n     \"from bokeh.resources import INLINE\\n\"+\n     \"output_notebook(resources=INLINE)\\n\"+\n     \"</code>\\n\"+\n     \"</div>\"}};\n\n  function display_loaded() {\n    var el = document.getElementById(\"1002\");\n    if (el != null) {\n      el.textContent = \"BokehJS is loading...\";\n    }\n    if (root.Bokeh !== undefined) {\n      if (el != null) {\n        el.textContent = \"BokehJS \" + root.Bokeh.version + \" successfully loaded.\";\n      }\n    } else if (Date.now() < root._bokeh_timeout) {\n      setTimeout(display_loaded, 100)\n    }\n  }\n\n\n  function run_callbacks() {\n    try {\n      root._bokeh_onload_callbacks.forEach(function(callback) {\n        if (callback != null)\n          callback();\n      });\n    } finally {\n      delete root._bokeh_onload_callbacks\n    }\n    console.debug(\"Bokeh: all callbacks have finished\");\n  }\n\n  function load_libs(css_urls, js_urls, callback) {\n    if (css_urls == null) css_urls = [];\n    if (js_urls == null) js_urls = [];\n\n    root._bokeh_onload_callbacks.push(callback);\n    if (root._bokeh_is_loading > 0) {\n      console.debug(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n      return null;\n    }\n    if (js_urls == null || js_urls.length === 0) {\n      run_callbacks();\n      return null;\n    }\n    console.debug(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n    root._bokeh_is_loading = css_urls.length + js_urls.length;\n\n    function on_load() {\n      root._bokeh_is_loading--;\n      if (root._bokeh_is_loading === 0) {\n        console.debug(\"Bokeh: all BokehJS libraries/stylesheets loaded\");\n        run_callbacks()\n      }\n    }\n\n    function on_error(url) {\n      console.error(\"failed to load \" + url);\n    }\n\n    for (let i = 0; i < css_urls.length; i++) {\n      const url = css_urls[i];\n      const element = document.createElement(\"link\");\n      element.onload = on_load;\n      element.onerror = on_error.bind(null, url);\n      element.rel = \"stylesheet\";\n      element.type = \"text/css\";\n      element.href = url;\n      console.debug(\"Bokeh: injecting link tag for BokehJS stylesheet: \", url);\n      document.body.appendChild(element);\n    }\n\n    const hashes = {\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.3.min.js\": \"dM3QQsP+wXdHg42wTqW85BjZQdLNNIXqlPw/BgKoExPmTG7ZLML4EGqLMfqHT6ON\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.3.min.js\": \"8x57I4YuIfu8XyZfFo0XVr2WAT8EK4rh/uDe3wF7YuW2FNUSNEpJbsPaB1nJ2fz2\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.3.min.js\": \"3QTqdz9LyAm2i0sG5XTePsHec3UHWwVsrOL68SYRoAXsafvfAyqtQ+h440+qIBhS\"};\n\n    for (let i = 0; i < js_urls.length; i++) {\n      const url = js_urls[i];\n      const element = document.createElement('script');\n      element.onload = on_load;\n      element.onerror = on_error.bind(null, url);\n      element.async = false;\n      element.src = url;\n      if (url in hashes) {\n        element.crossOrigin = \"anonymous\";\n        element.integrity = \"sha384-\" + hashes[url];\n      }\n      console.debug(\"Bokeh: injecting script tag for BokehJS library: \", url);\n      document.head.appendChild(element);\n    }\n  };\n\n  function inject_raw_css(css) {\n    const element = document.createElement(\"style\");\n    element.appendChild(document.createTextNode(css));\n    document.body.appendChild(element);\n  }\n\n  \n  var js_urls = [\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.3.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.3.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.3.min.js\"];\n  var css_urls = [];\n  \n\n  var inline_js = [\n    function(Bokeh) {\n      Bokeh.set_log_level(\"info\");\n    },\n    function(Bokeh) {\n    \n    \n    }\n  ];\n\n  function run_inline_js() {\n    \n    if (root.Bokeh !== undefined || force === true) {\n      \n    for (var i = 0; i < inline_js.length; i++) {\n      inline_js[i].call(root, root.Bokeh);\n    }\n    if (force === true) {\n        display_loaded();\n      }} else if (Date.now() < root._bokeh_timeout) {\n      setTimeout(run_inline_js, 100);\n    } else if (!root._bokeh_failed_load) {\n      console.log(\"Bokeh: BokehJS failed to load within specified timeout.\");\n      root._bokeh_failed_load = true;\n    } else if (force !== true) {\n      var cell = $(document.getElementById(\"1002\")).parents('.cell').data().cell;\n      cell.output_area.append_execute_result(NB_LOAD_WARNING)\n    }\n\n  }\n\n  if (root._bokeh_is_loading === 0) {\n    console.debug(\"Bokeh: BokehJS loaded, going straight to plotting\");\n    run_inline_js();\n  } else {\n    load_libs(css_urls, js_urls, function() {\n      console.debug(\"Bokeh: BokehJS plotting callback run at\", now());\n      run_inline_js();\n    });\n  }\n}(window));"
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from bokeh.plotting import output_notebook\n",
    "output_notebook()\n",
    "\n",
    "from bokeh.models import ColumnDataSource, DataTable, TableColumn\n",
    "from bokeh.plotting import show"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "c05707d2",
   "metadata": {
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [],
   "source": [
    "df_loc = df[df['Type of application'] =='AMD detection']\n",
    "df_loc = df_loc[['ID', 'Title', 'Journal', 'Type of application', 'Country']]\n",
    "\n",
    "columns = [TableColumn(field=Ci, title=Ci) for Ci in df_loc.columns]\n",
    "\n",
    "data_table_1 = DataTable(columns=columns, \n",
    "                       source=ColumnDataSource(df_loc),\n",
    "                       height = 300, \n",
    "                       width = 800,\n",
    "                       autosize_mode='fit_columns')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "7201222d",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "  <div class=\"bk-root\" id=\"070c036b-9fa1-4717-88f3-da389b59f86c\" data-root-id=\"1009\"></div>\n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "(function(root) {\n",
       "  function embed_document(root) {\n",
       "    \n",
       "  var docs_json = {\"21d942ba-db27-4fe8-95f3-31a303c78102\":{\"defs\":[],\"roots\":{\"references\":[{\"attributes\":{\"autosize_mode\":\"fit_columns\",\"columns\":[{\"id\":\"1003\"},{\"id\":\"1004\"},{\"id\":\"1005\"},{\"id\":\"1006\"},{\"id\":\"1007\"}],\"height\":300,\"source\":{\"id\":\"1008\"},\"view\":{\"id\":\"1011\"},\"width\":800},\"id\":\"1009\",\"type\":\"DataTable\"},{\"attributes\":{},\"id\":\"1021\",\"type\":\"StringEditor\"},{\"attributes\":{\"editor\":{\"id\":\"1013\"},\"field\":\"ID\",\"formatter\":{\"id\":\"1012\"},\"title\":\"ID\"},\"id\":\"1003\",\"type\":\"TableColumn\"},{\"attributes\":{},\"id\":\"1015\",\"type\":\"StringEditor\"},{\"attributes\":{\"source\":{\"id\":\"1008\"}},\"id\":\"1011\",\"type\":\"CDSView\"},{\"attributes\":{},\"id\":\"1020\",\"type\":\"StringFormatter\"},{\"attributes\":{},\"id\":\"1022\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1014\",\"type\":\"StringFormatter\"},{\"attributes\":{\"editor\":{\"id\":\"1017\"},\"field\":\"Journal\",\"formatter\":{\"id\":\"1016\"},\"title\":\"Journal\"},\"id\":\"1005\",\"type\":\"TableColumn\"},{\"attributes\":{},\"id\":\"1016\",\"type\":\"StringFormatter\"},{\"attributes\":{},\"id\":\"1013\",\"type\":\"StringEditor\"},{\"attributes\":{},\"id\":\"1023\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"1017\",\"type\":\"StringEditor\"},{\"attributes\":{\"editor\":{\"id\":\"1019\"},\"field\":\"Type of application\",\"formatter\":{\"id\":\"1018\"},\"title\":\"Type of application\"},\"id\":\"1006\",\"type\":\"TableColumn\"},{\"attributes\":{},\"id\":\"1018\",\"type\":\"StringFormatter\"},{\"attributes\":{\"data\":{\"Country\":[\"USA\",\"Canada\",\"USA\",\"USA\",\"Spain\",\"Russia\",\"Spain\",\"Russia\",\"Canada\",\"Spain\",\"Poland\"],\"ID\":[\"Ebraheem et al. (1990)\",\"Yuval et al. (1996)\",\"Benson et al. (1998)\",\"Campbell et al. (2000)\",\"Martinez-Pagan et al. (2009)\",\"Bortnikova et al. (2013)\",\"Rey et al. (2013)\",\"Korneeva et al. (2016)\",\"Tycholiz et al. (2016)\",\"Martin-Crespo et al. (2020)\",\"Pierwola et al. (2020)\"],\"Journal\":[\"Groundwater\",\"Journal of Applied Geophysics\",\"Environmental Geosciences\",\"ICARD\",\"Near Surface Geophysics\",\"Threats to the Quality of Groundwater Resources\",\"Catena\",\"International Journal of Advances in Science, Engineering and Technology\",\"Journal of Applied Geophysics\",\"Remote Sensing\",\"Environmental Science and Pollution Research\"],\"Title\":[\"A study of acid mine drainage using earth\\u00a0resistivity\\u00a0measurements\",\"DC resistivity and IP methods in acid mine drainage problems, results from the Copper Cliff mine tailings impoundments\",\"Detecting the Presence of Acid Mine Drainage Using Hydrogeological, Geochemical, and Geophysical Data, Applications to Contrasting Conditions at Mine Sites in Little Cottonwood and American Fork Canyons, Utah\",\"Geoelectrical methods for investigating mine dumps\",\"The use of 2D electrical tomography to assess pollution in slurry ponds of the Murcia Region, SE Spain\",\"The combination of geoelectrical measurements and hydro-geochemical studies for the evaluation of groundwater pollution in mining tailings areas\",\"Heavy metal pollution in the Quaternary Garza basin, A multidisciplinary study of the environmental risks posed by mining (Linares, southern Spain)\",\"A geochemical and geophysical characterization of acid mine drainage and sulfide tailings at Karabash mine site (South Ural, Russia)\",\"Geophysical delineation of acidity and salinity in the Central Manitoba gold mine tailings pile, Manitoba, Canada\",\"Abandoned Mine Tailings Affecting Riverbed Sediments in the Cartagena\\u2013La Union District, Mediterranean Coastal Area (Spain)\",\"Integrated geophysical and geochemical methods applied for recognition of acid waste drainage (AWD) from Zn-Pb post-flotation tailing pile (Olkusz, southern Poland)\"],\"Type of application\":[\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\",\"AMD detection\"],\"index\":[0,2,3,5,15,39,41,60,67,100,105]},\"selected\":{\"id\":\"1022\"},\"selection_policy\":{\"id\":\"1023\"}},\"id\":\"1008\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"editor\":{\"id\":\"1021\"},\"field\":\"Country\",\"formatter\":{\"id\":\"1020\"},\"title\":\"Country\"},\"id\":\"1007\",\"type\":\"TableColumn\"},{\"attributes\":{},\"id\":\"1019\",\"type\":\"StringEditor\"},{\"attributes\":{},\"id\":\"1012\",\"type\":\"StringFormatter\"},{\"attributes\":{\"editor\":{\"id\":\"1015\"},\"field\":\"Title\",\"formatter\":{\"id\":\"1014\"},\"title\":\"Title\"},\"id\":\"1004\",\"type\":\"TableColumn\"}],\"root_ids\":[\"1009\"]},\"title\":\"Bokeh Application\",\"version\":\"2.3.3\"}};\n",
       "  var render_items = [{\"docid\":\"21d942ba-db27-4fe8-95f3-31a303c78102\",\"root_ids\":[\"1009\"],\"roots\":{\"1009\":\"070c036b-9fa1-4717-88f3-da389b59f86c\"}}];\n",
       "  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);\n",
       "\n",
       "  }\n",
       "  if (root.Bokeh !== undefined) {\n",
       "    embed_document(root);\n",
       "  } else {\n",
       "    var attempts = 0;\n",
       "    var timer = setInterval(function(root) {\n",
       "      if (root.Bokeh !== undefined) {\n",
       "        clearInterval(timer);\n",
       "        embed_document(root);\n",
       "      } else {\n",
       "        attempts++;\n",
       "        if (attempts > 100) {\n",
       "          clearInterval(timer);\n",
       "          console.log(\"Bokeh: ERROR: Unable to run BokehJS code because BokehJS library is missing\");\n",
       "        }\n",
       "      }\n",
       "    }, 10, root)\n",
       "  }\n",
       "})(window);"
      ],
      "application/vnd.bokehjs_exec.v0+json": ""
     },
     "metadata": {
      "application/vnd.bokehjs_exec.v0+json": {
       "id": "1009"
      }
     },
     "output_type": "display_data"
    }
   ],
   "source": [
    "show(data_table_1)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "6a1b12e8",
   "metadata": {},
   "source": [
    ":::{note} \n",
    "**Cite us**: \n",
    "Dimech, A., Cheng, L.Z., Chouteau, M., Chambers, J.E., Uhlemann, S., & Wilkinson, P.B., Meldrum, P.I., Mary, B., Fabien-Ouellet, G., & Isabelle, A. (**2022**). A review on  applications of time-lapse electrical resistivity tomography over the last 30 years : perspectives for mining waste monitoring. \n",
    "_manuscript submitted_.\n",
    ":::\n",
    "\n",
    "[![DOI](https://zenodo.org/badge/465892724.svg)](https://zenodo.org/badge/latestdoi/465892724)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "398c644a",
   "metadata": {},
   "source": [
    "## Explore the 'ERT for mining waste' database"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "84819387",
   "metadata": {
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [],
   "source": [
    "df_loc = df.sort_values(['Year'], ascending=True)\n",
    "\n",
    "columns = [TableColumn(field=Ci, title=Ci) for Ci in df_loc.columns]\n",
    "\n",
    "data_table_2 = DataTable(columns=columns, \n",
    "                       source=ColumnDataSource(df_loc), \n",
    "                       height = 500,\n",
    "                       width = 800,\n",
    "                       autosize_mode='fit_columns')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "8ccf688a",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "  <div class=\"bk-root\" id=\"9f04c753-b515-41fc-936f-e9cb1963817d\" data-root-id=\"1092\"></div>\n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "(function(root) {\n",
       "  function embed_document(root) {\n",
       "    \n",
       "  var docs_json = {\"1d56559a-2410-4fe4-90c8-7ebf33df826f\":{\"defs\":[],\"roots\":{\"references\":[{\"attributes\":{\"autosize_mode\":\"fit_columns\",\"columns\":[{\"id\":\"1084\"},{\"id\":\"1085\"},{\"id\":\"1086\"},{\"id\":\"1087\"},{\"id\":\"1088\"},{\"id\":\"1089\"},{\"id\":\"1090\"}],\"height\":500,\"source\":{\"id\":\"1091\"},\"view\":{\"id\":\"1094\"},\"width\":800},\"id\":\"1092\",\"type\":\"DataTable\"},{\"attributes\":{},\"id\":\"1111\",\"type\":\"StringFormatter\"},{\"attributes\":{\"editor\":{\"id\":\"1120\"},\"field\":\"Province\",\"formatter\":{\"id\":\"1119\"},\"title\":\"Province\"},\"id\":\"1090\",\"type\":\"TableColumn\"},{\"attributes\":{\"editor\":{\"id\":\"1108\"},\"field\":\"ID\",\"formatter\":{\"id\":\"1107\"},\"title\":\"ID\"},\"id\":\"1084\",\"type\":\"TableColumn\"},{\"attributes\":{},\"id\":\"1107\",\"type\":\"StringFormatter\"},{\"attributes\":{},\"id\":\"1121\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1122\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"1110\",\"type\":\"StringEditor\"},{\"attributes\":{\"source\":{\"id\":\"1091\"}},\"id\":\"1094\",\"type\":\"CDSView\"},{\"attributes\":{\"editor\":{\"id\":\"1116\"},\"field\":\"Type of application\",\"formatter\":{\"id\":\"1115\"},\"title\":\"Type of application\"},\"id\":\"1088\",\"type\":\"TableColumn\"},{\"attributes\":{},\"id\":\"1112\",\"type\":\"StringEditor\"},{\"attributes\":{\"editor\":{\"id\":\"1118\"},\"field\":\"Country\",\"formatter\":{\"id\":\"1117\"},\"title\":\"Country\"},\"id\":\"1089\",\"type\":\"TableColumn\"},{\"attributes\":{\"editor\":{\"id\":\"1114\"},\"field\":\"Year\",\"formatter\":{\"id\":\"1113\"},\"title\":\"Year\"},\"id\":\"1087\",\"type\":\"TableColumn\"},{\"attributes\":{},\"id\":\"1109\",\"type\":\"StringFormatter\"},{\"attributes\":{},\"id\":\"1113\",\"type\":\"StringFormatter\"},{\"attributes\":{},\"id\":\"1108\",\"type\":\"StringEditor\"},{\"attributes\":{\"editor\":{\"id\":\"1110\"},\"field\":\"Title\",\"formatter\":{\"id\":\"1109\"},\"title\":\"Title\"},\"id\":\"1085\",\"type\":\"TableColumn\"},{\"attributes\":{\"data\":{\"Country\":[\"USA\",\"Canada\",\"Canada\",\"USA\",\"Sweden\",\"USA\",\"Australia\",\"United Kingdom\",\"USA\",\"Sweden\",\"Finland\",\"Sweden\",\"Iran\",\"India\",\"Spain\",\"Spain\",\"Canada\",\"Portugal\",\"USA\",\"USA\",\"USA\",\"USA\",\"Spain\",\"Finland\",\"Spain\",\"Canada\",\"Spain\",\"India\",\"Russia\",\"France\",\"Portugal\",\"Canada\",\"Spain\",\"Spain\",\"Iran\",\"Spain\",\"Spain\",\"France\",\"Morocco\",\"Russia\",\"Italy\",\"Spain\",\"Iran\",\"Spain\",\"Spain\",\"USA\",\"USA\",\"Iran\",\"Finland\",\"Sweden\",\"USA\",\"Poland\",\"Spain\",\"China\",\"Austalia\",\"Canada\",\"USA\",\"Sweden\",\"Canada\",\"Iran\",\"Iran \",\"Iran\",\"Spain\",\"Russia\",\"Spain\",\"Russia\",\"Germany\",\"USA\",\"Russia\",\"China\",\"USA\",\"USA\",\"USA\",\"Canada\",\"Canada\",\"Spain\",\"Morocco\",\"Russia\",\"France\",\"Canada\",\"Finland\",\"Spain\",\"Canada\",\"United Kingdom\",\"Brazil\",\"Russia\",\"Poland\",\"Spain\",\"Brazil\",\"Thailand\",\"Chile \",\"Iran\",\"USA\",\"Canada\",\"Spain\",\"Brazil\",\"Poland\",\"Peru\",\"Russia\",\"Spain\",\"Spain\",\"Germany\",\"Morocco\",\"Spain\",\"Brazil\",\"Australia\",\"Spain\",\"Chile\"],\"ID\":[\"Ebraheem et al. (1990)\",\"King et al. (1994)\",\"Yuval et al. (1996)\",\"Benson et al. (1998)\",\"Bergstrom (1998)\",\"Campbell et al. (2000)\",\"Buselli et al. (2001)\",\"Binley et al. (2003)\",\"Spindler et al. (2004)\",\"Sjodahl et al. (2005)\",\"Vanhala et al. (2005)\",\"Mainali (2006)\",\"Ardejani et al. (2008)\",\"Krishnamurthy et al. (2009)\",\"Martinez-Pagan et al. (2009)\",\"Martinez-Pagan et al. (2009)\",\"Poisson et al. (2009)\",\"Ramalho et al. (2009)\",\"Rucker et al. (2009)\",\"Rucker et al. (2009)\",\"Rucker et al. (2009)\",\"Rucker (2010)\",\"Martin-Crespo et al. (2010)\",\"Placencia-Gomez et al. (2010)\",\"Gomez-Ortiz et al. (2010)\",\"Anterrieu et al. (2010)\",\"Gomez-Ortiz et al. (2010)\",\"Banerjee et al. (2011)\",\"Bortnikova et al. (2011)\",\"Florsch et al. (2011)\",\"Grangeia et al. (2011)\",\"Maqsoud et al. (2011)\",\"Mart\\u00edn-Crespo et al. (2011)\",\"Martinez-Pagan et al. (2011)\",\"Nasab et al. (2011)\",\"Martinez et al. (2012)\",\"Martin-Crespo et al. (2012)\",\"Florsch et al. (2012)\",\"Lghoul et al. (2012)\",\"Bortnikova et al. (2013)\",\"Mele et al. (2013)\",\"Rey et al. (2013)\",\"Shiraz et al. (2013)\",\"Acosta et al. (2014)\",\"Martinez et al. (2014)\",\"Rucker et al. (2014)\",\"Rucker et al. (2014)\",\"Shokri et al. (2014)\",\"Placencia-Gomez et al. (2015)\",\"Villain et al. (2015)\",\"Rucker (2015)\",\"Pierwola (2015)\",\"Martin-Crespo et al. (2015)\",\"Li et al. (2015)\",\"Kuranchie et al. (2015)\",\"Booterbaugh et al. (2015)\",\"Bethune et al. (2015)\",\"Mainali et al. (2015)\",\"Tycholiz et al. (2016)\",\"Shokri et al. (2016)\",\"Shokri et al. (2016)\",\"Shafaei et al. (2016)\",\"Saladich et al. (2016)\",\"Olenchenko et al. (2016)\",\"Martinez et al. (2016)\",\"Korneeva et al. (2016)\",\"Gunther et al. (2016)\",\"Cubbage et al. (2016)\",\"Yurkevich et al. (2017)\",\"Lu et al. (2017)\",\"Johnston et al. (2017)\",\"Greer et al. (2017)\",\"Rucker et al. (2017)\",\"Dimech et al. (2017)\",\"Coulibaly et al. (2017)\",\"Cortada et al. (2017)\",\"Benyassine et al. (2017)\",\"Epov et al. (2017)\",\"Qi et al. (2018)\",\"Power et al. (2018)\",\"Markovaara et al. (2018)\",\"Martin-Crespo et al. (2018)\",\"Dimech et al. (2018)\",\"Hudson et al. (2018)\",\"Casagrande et al. (2018)\",\"Bortnikova et al. (2018)\",\"Klosowski et al. (2018)\",\"Vasconez-Maza et al. (2019)\",\"Targa et al. (2019)\",\"Puttiwongrak et al. (2019)\",\"Nikonow et al. (2019)\",\"Maghsoudy et al. (2019)\",\"Hester et al. (2019)\",\"Dimech et al. (2019)\",\"Martin-Crespo et al. (2019)\",\"Moreira et al. (2020)\",\"Pierwola et al. (2020)\",\"Paria et al. (2020)\",\"Olenchenko et al. (2020)\",\"Martinez-Segura et al. (2020)\",\"Rey et al. (2020)\",\"Martin et al. (2020)\",\"Lachhab et al. (2020)\",\"Gabarron et al. (2020)\",\"Casagrande et al. (2020)\",\"Canales et al. (2020)\",\"Martin-Crespo et al. (2020)\",\"Tresoldi et al. (2020)\"],\"Journal\":[\"Groundwater\",\"NaN\",\"Journal of Applied Geophysics\",\"Environmental Geosciences\",\"NaN\",\"ICARD\",\"Journal of Applied Geophysics\",\"Journal of Environmental and Engineering\",\"Environmental and Engineering Geoscience\",\"Environmental Geology\",\"Survey of Finland\",\"NaN\",\"International Journal of Environmental Science & Technology\",\"NaN\",\"Journal of Environmental and Engineering\",\"Near Surface Geophysics\",\"Journal of Applied Geophysics\",\"Journal of Applied Geophysics\",\"Mine Water and the Environment\",\"Hydrometallurgy\",\"Hydrometallurgy\",\"Geophysics\",\"Environmental Earth Sciences\",\"Environmental Earth Sciences\",\"Near Surface Geophysics\",\"Bulletin of Engineering Geology and the Environment\",\"Dyna\",\"Physics and Chemistry of the Earth\",\"Water Security in the Mediterranean Region\",\"Journal of Archaeological Science\",\"Engineering Geology\",\"Canadian Geotechnical Journal\",\"Water, Air and Soil Pollution\",\"Physics and Chemistry of the Earth\",\"Mine Water and the Environment\",\"Water, Air and Soil Pollution\",\"Journal of Geochemical Exploration\",\"Near Surface Geophysics\",\"Mine Water and the Environment\",\"Threats to the Quality of Groundwater Resources\",\"Environmental Monitoring and Assessment\",\"Catena\",\"Exploration Geophysics\",\"Journal of Geochemical Exploration\",\"International Journal of Mineral Processing\",\"Near Surface Geophysics\",\"Journal of Applied Geophysics\",\"Mine Water and the Environment\",\"Journal of Contaminant Hydrology\",\"Environmental Earth Sciences\",\"Hydrometallurgy\",\"Polish Journal of Environmental Studies\",\"Engineering Geology\",\"Journal of Central South University\",\"International Journal of Mining, Reclamation and Environment\",\"Journal of Environmental and Engineering\",\"Journal of Contaminant Hydrology\",\"Electronic Journal of Geotechnical Engineering\",\"Journal of Applied Geophysics\",\"International Journal of Coal Geology\",\"Environmental Earth Sciences\",\"Mine Water and the Environment\",\"Near Surface Geoscience\",\"Russian Geology and Geophysics\",\"Journal of Geochemical Exploration\",\"International Journal of Advances in Science, Engineering and Technology\",\"Journal of Applied Geophysics\",\"Proceedings of Heap Leach Mining Solutions\",\"Toxicological & Environmental Chemistry\",\"Mine Water and the Environment\",\"Mine Water and the Environment\",\"Hydrological Processes\",\"Hydrometallurgy\",\"Symposium on the Application of Geophysics to Engineering and Environmental Problems\",\"International Journal of Mining Science and Technology\",\"Engineering Geology\",\"Journal of Environmental and Engineering Geophysics\",\"Russian Geology and Geophysics\",\"Geophysics\",\"Journal of Applied Geophysics\",\"Resources Policy\",\"Engineering Geology\",\"Symposium on the Application of Geophysics to Engineering and Environmental Problems\",\"Water, Air and Soil Pollution\",\"Brazilian Journal of Geophysics\",\"Applied Geochemistry\",\"Applied Sciences\",\"Journal of Hazardous Materials\",\"Springer Nature Applied Sciences\",\"Journal of Cleaner Production\",\"Applied Geochemistry\",\"Mine Water and the Environment\",\"Science of the Total Environment\",\"Vadose Zone Journal\",\"Applied Geochemistry with Case Studies on Geological Formations, Exploration Techniques and Environmental Issues\",\"Springer Nature Applied Sciences\",\"Environmental Science and Pollution Research\",\"Brazilian Journal of Geophysics\",\"Journal of Environmental and Engineering Geophysics\",\"Science of the Total Environment\",\"Mine Water and the Environment\",\"Journal of Environmental and Engineering Geophysics\",\"Journal of Environmental and Engineering Geophysics\",\"Minerals\",\"Pure and Applied Geophysics\",\"Journal of Applied Geophysics\",\"Remote Sensing\",\"Proceedings Tailings and Mine Waste\"],\"Province\":[\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"Indiana\",\"Narke\",\"NaN\",\"NaN\",\"NaN\",\"Jharkhand\",\"NaN\",\"NaN\",\"Quebec\",\"NaN\",\"Montana\",\"Nevada\",\"Nevada\",\"Nevada\",\"Andalucia\",\"NaN\",\"NaN\",\"Quebec\",\"NaN\",\"NaN\",\"NaN\",\"Occitanie\",\"NaN\",\"Quebec\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"Occitanie\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"Murcia\",\"NaN\",\"NaN\",\"Colorado\",\"NaN\",\"NaN\",\"Norrbotten\",\"NaN\",\"NaN\",\"NaN\",\"Jilin\",\"NaN\",\"NaN\",\"NaN\",\"Vasterbotten\",\"NaN\",\"NaN\",\"Semnan\",\"NaN\",\"Catalona\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"Arizona\",\"Kemerovo\",\"NaN\",\"NaN\",\"Virginia\",\"Arizona\",\"Quebec\",\"Quebec\",\"Andalucia\",\"NaN\",\"Kemerovo\",\"New Aquitaine\",\"Nova-Scotia\",\"Western Finland\",\"Murcia\",\"Quebec\",\"NaN\",\"NaN\",\"Kemerovo\",\"NaN\",\"Murcia\",\"NaN\",\"NaN\",\"Santiago\",\"Kerman\",\"Virginia\",\"Quebec\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"NaN\",\"Murcia\",\"Andalucia\",\"Lower-Saxony\",\"NaN\",\"Murcia\",\"NaN\",\"South Australia\",\"NaN\",\"Santiago\"],\"Title\":[\"A study of acid mine drainage using earth\\u00a0resistivity\\u00a0measurements\",\"Applications of Geophysical Methods for Monitoring Acid Mine Drainage\",\"DC resistivity and IP methods in acid mine drainage problems, results from the Copper Cliff mine tailings impoundments\",\"Detecting the Presence of Acid Mine Drainage Using Hydrogeological, Geochemical, and Geophysical Data, Applications to Contrasting Conditions at Mine Sites in Little Cottonwood and American Fork Canyons, Utah\",\"Geophysical\\u00a0methods for investigating and monitoring the integrity of sealing layers on\\u00a0mining\\u00a0waste deposits\",\"Geoelectrical methods for investigating mine dumps\",\"Groundwater contamination monitoring with multichannel electrical and electromagnetic methods\",\"The performance of electrical methods for assessing the integrity of geomembrane liners in landfill caps and waste storage ponds\",\"Geophysical investigations at an abandoned mine site subjected to reclamation using a fixated scrubber sludge cap\",\"Using resistivity measurements for dam safety evaluation at Enemossen tailings dam in southern Sweden\",\"Geophysical characterizing of tailings impoundment-a case from the closed Hammaslahti Cu-Zn mine, eastern Finland\",\"Monitoring\\u00a0of\\u00a0tailings dams\\u00a0with\\u00a0geophysical methods\",\"A combined mathematical geophysical model for prediction of pyrite oxidation and pollutant leaching associated with a coal washing waste dump\",\"Electrical resistivity imaging technique\\u00a0to\\u00a0delineate coal seam barrier thickness\\u00a0and\\u00a0demarcate water filled voids\",\"Electrical resistivity imaging revealed the spatial properties of mine tailing ponds in the Sierra Minera of Southeast Spain\",\"The use of 2D electrical tomography to assess pollution in slurry ponds of the Murcia Region, SE Spain\",\"Geophysical experiments to image the shallow internal structure and the moisture distribution of a mine waste rock pile\",\"Using geophysical methods to characterize an abandoned uranium mining site, Portugal\",\"Electrical Resistivity Characterization of a Reclaimed Gold Mine to Delineate Acid Rock Drainage Pathways\",\"Three-dimensional electrical resistivity imaging of a gold heap\",\"Monitoring of a secondary recovery application of leachate injection into a heap\",\"Moisture estimation within a mine heap, An application of cokriging with assay data and electrical resistivity\",\"Monitoring study of the mine pond reclamation of Mina Concepcio\\u00b4n, Iberian Pyrite Belt (Spain)\",\"Integrated geophysical and geochemical study on AMD generation at the Haveri Au\\u2013Cu mine tailings, SW Finland\",\"Application of electrical resistivity tomography to the environmental characterization of abandoned massive sulphide mine ponds (Iberian Pyrite Belt, SW Spain)\",\"Geophysical characterization of the large-scale internal structure of a waste rock pile from a hard rock mine\",\"Geoenvironmental characterization of the san Quintin mine tailings, ciudad real (Spain)\",\"Delineation of subsurface structures using resistivity, VLF and radiometric measurement around a U-tailings pond and its hydrogeological implication\",\"Acid Mine Drainage Migration of Belovo Zinc Plant (South Siberia, Russia), A Multidisciplinary Study\",\"Quantification of slag heap volumes and masses through the use of induced polarization, application to the Castel-Minier site\",\"Mine tailings integrated investigations, The case of Rio tailings (Panasqueira Mine, Central Portugal)\",\"Field investigation of a suction break designed to control slope-induced desaturation in an oxygen barrier\",\"A geochemical and geophysical characterization of sulfide mine ponds at the Iberian Pyrite Belt (Spain)\",\"A multidisciplinary study for mining landscape reclamation, a study case on two tailing ponds in the Region of Murcia (SE Spain)\",\"Successful use of geoelectrical surveys in Area 3 of the Gol-e-Gohar iron ore mine, Iran\",\"Characterizing Abandoned Mining Dams by Geophysical (ERI) and Geochemical Methods, The Linares-La Carolina District (Southern Spain)\",\"Geoenvironmental characterization of riverbeds affected by mine tailings in the Mazarr\\u00f3n district (Spain)\",\"Induced polarization 3D tomography of an archaeological direct reduction slag heap\",\"Electrical and seismic tomography used to image the structure of a tailings pond at the abandoned Kettara mine, Morocco\",\"The combination of geoelectrical measurements and hydro-geochemical studies for the evaluation of groundwater pollution in mining tailings areas\",\"Characterisation of sulphide-bearing waste-rock dumps using electrical resistivity imaging, the case study of the Rio Marina mining district (Elba Island, Italy)\",\"Heavy metal pollution in the Quaternary Garza basin, A multidisciplinary study of the environmental risks posed by mining (Linares, southern Spain)\",\"Investigating the source of contaminated plumes downstream of the Alborz Sharghi coal washing plant using EM34 conductivity data, VLF-EM and DC-resistivity geophysical methods\",\"Assessment of environmental risk of reclaimed mining ponds using geophysics and geochemical techniques\",\"Influence of measurement conditions on the resolution of electrical resistivity imaging, The example of abandoned mining dams in the La Carolina District (Southern Spain)\",\"Real-time electrical monitoring of reagent delivery during a subsurface amendment experiment\",\"Investigating motion blur and temporal aliasing from time-lapse electrical resistivity\",\"Integrated Time-Lapse Geoelectrical\\u2013Geochemical Investigation at a Reactive Coal Washing Waste Pile in Northeastern Iran\",\"Spectral induced polarization (SIP) response of mine tailings\",\"Evaluation of the effectiveness of backfilling and sealing at an open-pit mine using ground penetrating radar and geoelectrical surveys, Kimheden, northern Sweden\",\"Deep well rinsing of a copper oxide heap\",\"Using Geoelectrical Imaging to Recognize Zn-Pb Post-Mining Waste Deposits\",\"Abandoned mine tailings in cultural itineraries, Don Quixote Route (Spain)\",\"Safety assessment of waste rock dump built on existing tailings ponds\",\"Electrical resistivity of iron ore mine tailings produced in Western Australia\",\"Geophysical Characterization of an Undrained Dyke Containing an Oil Sands Tailings Pond, Alberta, Canada\",\"Non-invasive flow path characterization in a mining-impacted wetland\",\"Tailings dams monitoring in Swedish mines using self-potential and electrical resistivity methods\",\"Geophysical delineation of acidity and salinity in the Central Manitoba gold mine tailings pile, Manitoba, Canada\",\"Predicting pyrite oxidation and multi-component reactive transport processes from an abandoned coal waste pile by comparing 2D numerical modeling and 3D geo-electrical inversion\",\"Mapping the flow pathways and contaminants transportation around a coal washing plant using the VLF-EM, Geo-electrical and IP techniques\\u2014A case study, NE Iran\",\"Detecting the source of contaminant zones down-gradient of the alborz sharghi coal washing plant using geo-electrical methods, northeastern Iran\",\"Geophysical evaluation of the volume of a mine tailing dump (Osor, Girona, NE Spain) using ERT\",\"Vertical and lateral spreading of highly mineralized acid drainage solutions (Ur dump, Salair), electrical resistivity tomography and hydrogeochemical data\",\"A multidisciplinary characterization of a tailings pond in the Linares-La Carolina mining district, Spain\",\"A geochemical and geophysical characterization of acid mine drainage and sulfide tailings at Karabash mine site (South Ural, Russia)\",\"Spectral two-dimensional inversion of frequency-domain induced polarization data from a mining slag heap\",\"Geophysical heap characterization throughout construction and operations of the Carlota Mine\",\"Geophysical investigations for evaluation of environmental pollution in a mine tailings area\",\"A Review of\\u00a0Geophysical Exploration Technology for\\u00a0Mine Water Disaster in\\u00a0China, Applications and\\u00a0Trends\",\"Exploration of diffuse and discrete sources of acid mine drainage to a headwater mountain stream in Colorado, USA\",\"Electrical resistivity imaging of hydrologic flow through surface coal mine valley fills with comparison to other landforms\",\"Drawing down the remaining copper inventory in a leach pad by way of subsurface leaching\",\"Monitoring water infiltration in an experimental waste rock pile with time-lapse ERT and multi-parameter data collection\",\"Numerical analysis and geophysical monitoring for stability assessment of the Northwest tailings dam at Westwood Mine\",\"Assessment of tailings pond seals using geophysical and hydrochemical techniques\",\"An application of electrical resistivity tomography to investigate heavy metals pathways\",\"Analysis of mine waste by geocheimical and geophysical methods (a case study of the mine tailing dump of the Salair ore-processing plant)\",\"Induced polarization response\\u00a0of\\u00a0porous media\\u00a0with\\u00a0metallic particles\\u2014Part 7,\\u00a0Detection\\u00a0and\\u00a0quantification\\u00a0of\\u00a0buried slag heaps\",\"Combined DC resistivity and induced polarization (DC-IP) for mapping the internal composition of a mine waste rock pile in Nova Scotia, Canada\",\"Preliminary volume and concentration estimation of the Aijala tailings pond\\u2013Evaluation of geophysical methods\",\"Geoenvironmental characterization of unstable abandoned mine tailings combining geophysical and geochemical methods (Cartagena-La Union district, Spain)\",\"3D time-lapse geoelectrical monitoring of moisture content in an experimental waste rock pile, Validation using hydrogeological data\",\"Integrated Hydrological and Geophysical Characterisation of Surface and Subsurface Water Contamination at Abandoned Metal Mines\",\"Integration of geophysical methods in the study of acid drainage in uranium mining waste\",\"Characterization of a gold extraction plant environment in assessing the hazardous nature of accumulated wastes (Kemerovo region, Russia)\",\"Increasing the reliability of flood embankments with neural imaging method\",\"Predicting spatial distribution of heavy metals in an abandoned phosphogypsum pond combining geochemistry, electrical resistivity tomography and statistical methods\",\"Structural analysis and geophysical survey for hydrogeological diagnosis in uranium mine, Po\\u00e7os de Caldas (Brazil)\",\"Application of multi-monitoring methods to investigate the contamination levels and dispersion of Pb and Zn from tin mining in coastal sediments at Saphan Hin, Phuket, Thailand\",\"A multidisciplinary approach considering geochemical reorganization and internal structure of tailings impoundments for metal exploration\",\"Application of Geo-electrical Tomography in Coupled Hydro-mechanical\\u2013Chemical Investigations in Heap Leaching\",\"Variability of subsurface structure and infiltration hydrology among surface coal mine valley fills\",\"Three dimensional time?lapse geoelectrical monitoring of water infiltration in an experimental mine waste rock pile\",\"Geoenvironmental characterization of sulfide mine tailings\",\"Hydrogelogical characterization of a waste rock pile and bedrock affected by acid mine drainage from geophysical survey\",\"Integrated geophysical and geochemical methods applied for recognition of acid waste drainage (AWD) from Zn-Pb post-flotation tailing pile (Olkusz, southern Poland)\",\"Geophysical-geotechnical investigation of an old tailings dam from a mine in the peruvian highland\",\"Electrical Resistivity Dynamics Beneath the Weathered Mine Tailings in Response to Ambient Temperature\",\"Volumetric characterisation of waste deposits generated during the production of fertiliser derived from phosphoric rock by using LiDAR and electrical resistivity tomography\",\"Assessment of\\u00a0Tailings Ponds by\\u00a0a\\u00a0Combination of\\u00a0Electrical (ERT and\\u00a0IP) and\\u00a0Hydrochemical Techniques (Linares, Southern Spain)\",\"Geophysical Exploration of a Historical Stamp Mill Dump for the Volume Estimation of Valuable Residues\",\"Integration of multi-geophysical approaches to identify potential pathways of heavy metals contamination-A case study in Zeida, Morocco\",\"Electrical Resistivity Tomography as a Support Tool for Physicochemical Properties Assessment of Near-Surface Waste Materials in a Mining Tailing Pond (El Gorguel, SE Spain)\",\"Study of generation and underground flow of acid mine drainage in waste rock pile in an uranium mine using electrical resistivity tomography\",\"Geoelectric interpretation of petrophysical and hydrogeological parameters in reclaimed mine tailings areas\",\"Abandoned Mine Tailings Affecting Riverbed Sediments in the Cartagena\\u2013La Union District, Mediterranean Coastal Area (Spain)\",\"Permanent Geoelectrical Monitoring of Tailings Dams Using the Autonomous G. RE. TA System\"],\"Type of application\":[\"AMD detection\",\"AMD monitoring\",\"AMD detection\",\"AMD detection\",\"Geochemical stability\",\"AMD detection\",\"AMD monitoring\",\"Geochemical stability\",\"Geochemical stability\",\"Geotechnical stability\",\"Characterization\",\"Geotechnical stability\",\"Geochemical stability\",\"Journal of the Geological Society of India\",\"Characterization\",\"AMD detection\",\"Characterization\",\"Characterization\",\"Geochemical stability\",\"Heap leach pad\",\"Heap leach pad\",\"Heap leach pad\",\"Geochemical stability\",\"AMD monitoring\",\"Characterization\",\"Characterization\",\"Characterization\",\"Characterization\",\"AMD monitoring\",\"Volume estimation\",\"Characterization\",\"Geochemical stability\",\"Characterization\",\"Characterization\",\"Characterization\",\"Characterization\",\"Characterization\",\"Volume estimation\",\"Characterization\",\"AMD detection\",\"Characterization\",\"AMD detection\",\"AMD monitoring\",\"Geochemical stability\",\"Characterization\",\"Heap leach pad\",\"Heap leach pad\",\"Characterization\",\"Characterization\",\"Geochemical stability\",\"Heap leach pad\",\"Characterization\",\"Characterization\",\"Geotechnical stability\",\"Characterization\",\"Characterization\",\"AMD monitoring\",\"Geotechnical stability\",\"AMD detection\",\"AMD monitoring\",\"AMD monitoring\",\"AMD monitoring\",\"Volume estimation\",\"AMD monitoring\",\"Characterization\",\"AMD detection\",\"Volume estimation\",\"Heap leach pad\",\"Characterization\",\"Geotechnical stability\",\"AMD monitoring\",\"Characterization\",\"Heap leach pad\",\"Characterization\",\"Geotechnical stability\",\"Geochemical stability\",\"AMD monitoring\",\"Characterization\",\"Volume estimation\",\"Characterization\",\"Volume estimation\",\"Characterization\",\"Geochemical stability\",\"AMD monitoring\",\"AMD monitoring\",\"AMD monitoring\",\"Geotechnical stability\",\"Characterization\",\"Characterization\",\"AMD monitoring\",\"Volume estimation\",\"Heap leach pad\",\"Characterization\",\"Geochemical stability\",\"Characterization\",\"AMD monitoring\",\"AMD detection\",\"Geotechnical stability\",\"Characterization\",\"Volume estimation\",\"Geochemical stability\",\"Volume estimation\",\"AMD monitoring\",\"Characterization\",\"AMD monitoring\",\"Characterization\",\"AMD detection\",\"Geotechnical stability\"],\"Year\":[1990,1994,1996,1998,1998,2000,2001,2003,2004,2005,2005,2006,2008,2009,2009,2009,2009,2009,2009,2009,2009,2010,2010,2010,2010,2010,2010,2011,2011,2011,2011,2011,2011,2011,2011,2012,2012,2012,2012,2013,2013,2013,2013,2014,2014,2014,2014,2014,2015,2015,2015,2015,2015,2015,2015,2015,2015,2015,2016,2016,2016,2016,2016,2016,2016,2016,2016,2016,2017,2017,2017,2017,2017,2017,2017,2017,2017,2017,2018,2018,2018,2018,2018,2018,2018,2018,2018,2019,2019,2019,2019,2019,2019,2019,2019,2020,2020,2020,2020,2020,2020,2020,2020,2020,2020,2020,2020,2020],\"index\":[0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,26,24,25,22,21,23,27,28,29,30,31,32,33,34,38,37,35,36,39,40,41,42,43,44,45,46,47,55,57,56,54,53,51,50,49,48,52,67,66,65,64,63,62,61,60,59,58,77,75,74,73,76,71,70,69,68,72,86,85,84,83,80,81,79,78,82,94,93,92,91,89,88,87,90,102,105,104,103,101,106,99,98,97,96,95,100,107]},\"selected\":{\"id\":\"1121\"},\"selection_policy\":{\"id\":\"1122\"}},\"id\":\"1091\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"1120\",\"type\":\"StringEditor\"},{\"attributes\":{},\"id\":\"1115\",\"type\":\"StringFormatter\"},{\"attributes\":{},\"id\":\"1114\",\"type\":\"StringEditor\"},{\"attributes\":{},\"id\":\"1116\",\"type\":\"StringEditor\"},{\"attributes\":{},\"id\":\"1117\",\"type\":\"StringFormatter\"},{\"attributes\":{},\"id\":\"1118\",\"type\":\"StringEditor\"},{\"attributes\":{},\"id\":\"1119\",\"type\":\"StringFormatter\"},{\"attributes\":{\"editor\":{\"id\":\"1112\"},\"field\":\"Journal\",\"formatter\":{\"id\":\"1111\"},\"title\":\"Journal\"},\"id\":\"1086\",\"type\":\"TableColumn\"}],\"root_ids\":[\"1092\"]},\"title\":\"Bokeh Application\",\"version\":\"2.3.3\"}};\n",
       "  var render_items = [{\"docid\":\"1d56559a-2410-4fe4-90c8-7ebf33df826f\",\"root_ids\":[\"1092\"],\"roots\":{\"1092\":\"9f04c753-b515-41fc-936f-e9cb1963817d\"}}];\n",
       "  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);\n",
       "\n",
       "  }\n",
       "  if (root.Bokeh !== undefined) {\n",
       "    embed_document(root);\n",
       "  } else {\n",
       "    var attempts = 0;\n",
       "    var timer = setInterval(function(root) {\n",
       "      if (root.Bokeh !== undefined) {\n",
       "        clearInterval(timer);\n",
       "        embed_document(root);\n",
       "      } else {\n",
       "        attempts++;\n",
       "        if (attempts > 100) {\n",
       "          clearInterval(timer);\n",
       "          console.log(\"Bokeh: ERROR: Unable to run BokehJS code because BokehJS library is missing\");\n",
       "        }\n",
       "      }\n",
       "    }, 10, root)\n",
       "  }\n",
       "})(window);"
      ],
      "application/vnd.bokehjs_exec.v0+json": ""
     },
     "metadata": {
      "application/vnd.bokehjs_exec.v0+json": {
       "id": "1092"
      }
     },
     "output_type": "display_data"
    }
   ],
   "source": [
    "show(data_table_2)"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "colab": {
   "collapsed_sections": [],
   "name": "1_database_mining_waste.ipynb",
   "provenance": []
  },
  "iooxa": null,
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.6.3"
  },
  "nteract": {
   "version": "0.28.0"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
